@@ -45,6 +45,7 @@ def check_virtualenv(path):
 
 
 def install_virtualenv(install_path=""):
+    # TODO: set python as parameter, this doesn't work for all the version (but it's ok for RH6)
     cmd = ["virtualenv", "-p", "/usr/local/bin/python2.7", virtualenv_path]
     print cmd
     output = subprocess.check_call(cmd)
@@ -59,7 +60,8 @@ def install_pip(name, install_path="", virtualenv=True, upgrade=False):
     for n in name:
         cmd.append(n)
     if upgrade:
-        cmd.append("--upgrade")
+        if len(name) == 1:
+            cmd.append("--upgrade")
     print cmd
     output = subprocess.check_call(cmd)
     print output
